=================
Test presentation
=================

Section 1
=========

Sub 1-1
-------

First content

Sub 1-2
-------

Second content [#f1]_

.. [#f1] This is footnote (rendered left-bottom of layout using sphinx.revealjs.footnotes ).

Section 2
=========

Sub 2-1
-------

End
